DataStateRetry

Struct DataStateRetry 

pub struct DataStateRetry<T, E = Error>
where E: ErrorBounds,
{ pub max_attempts: u8, pub retry_delay_millis: Range<u16>, /* private fields */ }
Automatically retries with a delay on failure until attempts are exhausted

Fields

max_attempts: u8

Number of attempts that the retries get reset to

retry_delay_millis: Range<u16>

The range of milliseconds to select a random value from to set the delay to retry

Implementations

Source

impl<T, E> DataStateRetry<T, E>
where E: ErrorBounds,

pub fn new( max_attempts: u8, retry_delay_millis: Range<u16>, ) -> DataStateRetry<T, E>

Creates a new instance of DataStateRetry

pub fn attempts_left(&self) -> u8

The number times left to retry before stopping trying

pub fn next_allowed_attempt(&self) -> u128

The number of millis after the epoch that an attempt is allowed

pub fn inner(&self) -> &DataState<T, E>

Provides access to the inner DataState

pub fn into_inner(self) -> DataState<T, E>

Consumes self and returns the unwrapped inner

pub fn present(&self) -> Option<&T>

Provides access to the stored data if available (returns Some if self.inner is Data::Present(_))

pub fn present_mut(&mut self) -> Option<&mut T>

Provides mutable access to the stored data if available (returns Some if self.inner is Data::Present(_))

pub fn egui_start_or_poll<F, R>( &mut self, ui: &mut Ui, retry_msg: Option<&str>, f: F, ) -> CanMakeProgress
where F: FnOnce() -> R, R: Into<Awaiting<T, E>>,

Attempts to load the data and displays appropriate UI if applicable.

Note see [DataState::egui_get] for more info.

pub fn start_or_poll<F, R>(&mut self, f: F) -> CanMakeProgress
where F: FnOnce() -> R, R: Into<Awaiting<T, E>>,

Attempts to load the data and returns if it is able to make progress.

pub fn reset_attempts(&mut self)

Resets the attempts taken

pub fn clear(&mut self)

Clear stored data

pub fn is_present(&self) -> bool

Returns true if the internal data state is DataState::Present.

pub fn is_awaiting_response(&self) -> bool

Returns true if the internal data state is DataState::AwaitingResponse.

pub fn is_none(&self) -> bool

Returns true if the internal data state is DataState::None.